export interface CircuitBreakerOptions {
    /** milliseconds */
    windowDuration?: number;
    numBuckets?: number;
    /** milliseconds */
    timeoutDuration?: number;
    /** percentage */
    errorThreshold?: number;
    /** absolute number */
    volumeThreshold?: number;
    onCircuitOpen?: (m: Metrics) => void;
    onCircuitClose?: (m: Metrics) => void;
}
export interface Metrics {
    totalCount: number;
    errorCount: number;
    errorPercentage: number;
}
export declare type Command = (success: () => void, failure: () => void) => void;
export interface CircuitBreakerPublicApi {
    run(command: Command, fallback?: () => void): void;
    forceClose(): void;
    forceOpen(): void;
    unforce(): void;
    isOpen(): boolean;
}
export declare class CircuitBreaker implements CircuitBreakerPublicApi {
    windowDuration: number;
    timeoutDuration: number;
    errorThreshold: number;
    volumeThreshold: number;
    onCircuitOpen: (m: Metrics) => void;
    onCircuitClose: (m: Metrics) => void;
    private readonly buckets;
    private bucketIndex;
    private state;
    private forced?;
    constructor(options?: CircuitBreakerOptions);
    run(command: Command, fallback?: () => void): void;
    forceClose(): void;
    forceOpen(): void;
    unforce(): void;
    isOpen(): boolean;
    private startTicker;
    private lastBucket;
    private executeCommand;
    private executeFallback;
    private calculateMetrics;
    private updateState;
}
