export declare function operation(options: OperationOptions, fn: (currentAttempt: number) => void): RetryOperation;
export declare function timeouts(options: OperationOptions): number[];
export interface OperationOptions extends CreateTimeoutOptions {
    /**
     * The maximum amount of times to retry the operation.
     * @default 0
     */
    retries: number;
}
interface CreateTimeoutOptions {
    /**
     * The exponential factor to use.
     * @default 2
     */
    factor: number;
    /**
     * The number of milliseconds before starting the first retry.
     * @default 200
     */
    minTimeout: number;
    /**
     * The maximum number of milliseconds between two retries.
     * @default 400
     */
    maxTimeout: number;
    /**
     * Randomizes the timeouts by multiplying a factor between 1-2.
     * @default true
     */
    randomize: boolean;
}
declare class RetryOperation {
    private readonly _timeouts;
    private readonly _fn;
    private _attempts;
    constructor(timeouts: number[], fn: (currentAttempt: number) => void);
    retry(): boolean;
    attempt(): void;
}
export {};
