"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
function operation(options, fn) {
    return new RetryOperation(timeouts(options), fn);
}
exports.operation = operation;
function timeouts(options) {
    if (options.minTimeout > options.maxTimeout) {
        throw new Error("minTimeout is greater than maxTimeout");
    }
    const timeouts = [];
    for (let i = 0; i < options.retries; i++) {
        timeouts.push(createTimeout(i, options));
    }
    // sort the array numerically ascending
    timeouts.sort(function (a, b) {
        return a - b;
    });
    return timeouts;
}
exports.timeouts = timeouts;
function createTimeout(attempt, opts) {
    const random = opts.randomize ? Math.random() + 1 : 1;
    let timeout = Math.round(random * opts.minTimeout * Math.pow(opts.factor, attempt));
    timeout = Math.min(timeout, opts.maxTimeout);
    return timeout;
}
class RetryOperation {
    constructor(timeouts, fn) {
        this._timeouts = timeouts;
        this._fn = fn;
        this._attempts = 1;
    }
    retry() {
        if (this._attempts > this._timeouts.length) {
            return false;
        }
        let timeout = this._timeouts[this._attempts - 1];
        setTimeout(() => {
            this._attempts++;
            this._fn(this._attempts);
        }, timeout);
        return true;
    }
    attempt() {
        this._fn(this._attempts);
    }
}
//# sourceMappingURL=retry.js.map